@@ -1,3 +1,3 @@
 
 def determine_chunk_size(num_workers):
-    return num_workers * 1000
\ No newline at end of file
+    return 2000
